@@ -11,7 +11,7 @@ from libreflow.rouge import _version as project_version
 
 from libreflow.baseflow import (
     ProjectSettings as BaseProjectSettings,
-    MultisiteConfig,
+    MultisiteConfig as BaseMultisiteConfig,
     SynchronizeFiles,
     KitsuConfig,
     LoginPage,
@@ -19,7 +19,7 @@ from libreflow.baseflow import (
 )
 from libreflow.baseflow.film import FilmCollection
 from libreflow.baseflow.task_manager import TaskManager
-from libreflow.baseflow.users import Users, UserProfile, UserEnvironment
+from libreflow.baseflow.users import Users, UserEnvironment
 from libreflow.baseflow.site import GotoCurrentSiteQueue
 from libreflow.baseflow.runners import (
     Blender,
@@ -32,7 +32,7 @@ from .entity_manager import EntityManager
 from .film import Film
 from .shot import Shot
 from .task import Task
-from .users import User
+from .users import User, UserProfile
 from .site import WorkingSite
 from .file import (
     TrackedFile,
@@ -78,6 +78,20 @@ class Synchronization(flow.Object):
             )
 
 
+class MultisiteConfig(BaseMultisiteConfig):
+
+    enable_user_workspace = flow.Computed(cached=True).ui(editor='bool')
+
+    def compute_child_value(self, child_value):
+        if child_value is self.enable_user_workspace:
+            site = self.root().project().get_current_site()
+            self.enable_user_workspace.set(
+                site.enable_user_workspace.get()
+            )
+        else:
+            super(MultisiteConfig, self).compute_child_value(child_value)
+
+
 class Admin(flow.Object):
 
     ICON = ('icons.gui', 'user-admin')
@@ -143,11 +157,21 @@ class Project(flow.Object):
         if context_name == 'settings':
             return dict(path_format='{film}/{shot}/{file}_{revision}')
 
-    def get_root(self, alternative=None):
+    def get_root(self, alternative=None, user_workspace=False):
         '''
-        alternative can be used if root_dir.get() returns None
+        Return the root directory of the project configured
+        for the current site, or, if `user_workspace` is True
+        and the `enable_user_workspace` option of the current
+        site is enabled, the working directory of the current
+        user.
         '''
-        root_dir = self.admin.multisites.root_dir.get()
+        site_config = self.admin.multisites
+        user_config = self.user
+
+        if user_workspace and site_config.enable_user_workspace.get():
+            root_dir = user_config.working_dir.get()
+        else:
+            root_dir = site_config.root_dir.get()
         
         if root_dir is None and alternative is not None:
             root_dir = alternative
